=========================
Serveliza's documentation
=========================

.. include:: ../README.rst
        :start-line: 4


Contents
---------

.. toctree::
   :maxdepth: 2

   installation
   usage
   reference
   contributing
   authors
   history

Index's
-------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
